/**
 *  Captain Beefy
 *  @author Drakkos
 *  @started 08/10/2008
 *
 *  If you change this file, please also update it in LPC for Dummies.
 */

// This is the include file that tells our code where to find the armoury.
// Notice that the name of the .h file is enclosed in angle brackets rather 
// than quotation marks.  If you surround the name in angle brackets, the 
// driver looks for the file in /include/ first, and then in its current 
// working directory. If you surround the name in quotation marks, it looks 
// in the working directory first and *then* in /include/.
#include <armoury.h>

// If we want to create a basic NPC, this is the file we inherit.
inherit "/obj/monster";

void setup() {
  
  // This sets up a variable of type object.  We can refer to this by the 
  // identifier 'trousers'.  All variables are defined at the top of a 
  // function, but are usually assigned elsewhere.  
  object trousers;
  // This sets up a second variable for the NPC's shirt.
  object shirt;

  // The name of the NPC is how it is identified by the MUD's matching 
  // system.  This should be one single word - it should usually too be 
  // the last word in the short, for simplicity's sake.  
  set_name ("beefy");
  // This is what players see when they encounter the NPC.
  set_short ("Captain Beefy");
  
  // This is what gets prepended to the short of the NPC.  Since Captain 
  // Beefy is a unique person, he gets his determinate set to empty.  If 
  // he was one of a number of clones (for example, a beggar), then 
  // the determinate could be set to 'a', or even 'the'.
  add_property ("determinate", "");

  // Captain Beefy is a unique NPC - there should only ever be one of him.  
  // This code doesn't ensure that, but it does mean when he's killed he'll 
  // trigger a death inform. 
  add_property ("unique", 1);
  
  // The name is used to match an NPC, but we also need to set valid 
  // adjectives.  If we don't include this, our NPC can be referred to as 
  // 'beefy', but not 'captain beefy'.  We want both to be valid.
  add_adjective ("captain");
  
  // We also want people to be able to refer to him just as 'captain', so 
  // we add an alias for him.  
  add_alias ("captain");
  
  // He needs a gender, because he's a he.  Setting the gender to 1 makes 
  // him male.  2 makes him female.  Everything else makes him an 'it'.
  set_gender (1);

  // The long is what players see when they 'look' at him.
  set_long ("This is Captain Beefy, a former officer in Duchess Saturday's "
    "Musketeers.  He retired from there after being stabbed in the face by "
    "a marauding player.  He now lives in Learnville, hoping to the Gods "
    "that he will die in his sleep before he is murdered for his shoes.\n");
    
  // You need this in the code, or try as you might he won't clone when you 
  // want him to.  The first piece of information we provide is his race.  
  // The second is his guild.  The third is his guild level. 
  basic_setup ("human", "warrior", 150);

  // If you want your NPC to be anything other than a mute, you need to 
  // set him up with a nationality.  We're using Genua here as an example, 
  // but your domain leader will be able to tell you which you should be 
  // using for your own domain.
  setup_nationality ("/std/nationality/genua", "genua");
 
  // This sets up the random chats for the NPC.  The first number dictates 
  // how often a random chat is made.  Every two seconds, the mud rolls 
  // a one-thousand sided dice (metaphorically), and if the result is 
  // lower than the number set here, the NPC will make a chat.  
  //
  // Each of the chats has two parts - a weighting, and a command string.  
  // The weighting is the relative chance a chat will be selected.  The 
  // string is the command that will be sent for the NPC to perform.
  //
  // If you want the NPC to say something, then start the command with a '
  // If you want the NPC to emote, then start the command with a :
  // If you want the NPC to perform a soul, start the command with a @.
  //
  // There's more you can do with this, including targetting specific people
  // in a room.  We'll get to that later.
    
  load_chat(20, ({ 
    2, "' Please don't hurt me.",
    1, "@cower",
    1, "' Here come the drums!",
    1, ": stares into space.",
    // The following chat uses a special substitution code to provide 
    // a context sensitive expansion.
    1, "' Oh, hello there $lcname$.",
  }));

  // This works exactly the same was load_chat, except the chats are 
  // made only while in combat.
  load_a_chat(40, ({ 
    1, "' Oh please, not again!",
    1, "' I don't get medical insurance!",
    1, "@weep",
  }));
 
  // The syntax for add_respond_to_with is not the simplest in the world, 
  // so the examples here will go over multiple possible syntaxes.  The 
  // first here is responding to a simple 'say' as long as it contains 
  // the word 'hello', 'hi', or 'hiya'.
  add_respond_to_with( 
    ({ 
        // This is the type of player command to respond to.
        "@say", 
        // This is the text to match on.  
       ({"hello", "hi", "hiya"}),
    }), 
      // This is the response the NPC will make.
      "' Er, hello.  Please don't kill me.");

  // This is a slightly more complex syntax, but works in the same way.
  // The difference is in how many sets of trigger words we provide - 
  // we provide one set (won't, not, and can't) and a second set 
  // (kill and murder).  Only said phrases that contain a word from 
  // the first set followed by a word from the second set will trigger
  // the response.
  add_respond_to_with( 
    ({ 
        "@say", 
       ({"won't", "not", "can't"}),
       ({"kill", "murder"}),
    }), 
      "' Thank you, kind sir!");
  // This is the same as the previous response.  The order in which responses
  // are added is important - the MUD will only invoke a response from the 
  // first match it finds.
  add_respond_to_with( 
    ({ 
        "@say", 
       ({"am", "will", "going"}),
       ({"kill", "murder"}),
    }), 
      "' No, please no.  I beg you!");

  // This is an example of an add_respond_to_with that has both multiple 
  // triggers (the souls comfort, soothe and calm) and multiple responses.
  add_respond_to_with( 
    ({ 
       ({"@comfort", "@soothe", "@calm"}), 
       ({"you"}),
    }), 
    ({
      ": takes a deep breath.",
      "' Yes, you're right... I shouldn't let things get to me."
    })
  );

  // Send a request to the ARMOURY to provide us with a pair of pirate 
  // trousers at 100% condition.
  trousers = ARMOURY->request_item ("pirate trousers", 100);
  // Move those trousers into the inventory of our NPC.
  trousers->move (this_object());

  // Send a request to the ARMOURY to provide us with a white ruffled 
  // shirt at 100% condition.
  shirt= ARMOURY->request_item ("white ruffled shirt", 100);
  // Move that shirt into the inventory of our NPC.
  shirt->move (this_object());
  
  // Make the NPC wear and hold everything in his inventory.
  init_equip();
}
  

   